@@ -212,8 +212,7 @@ def _create_context_aware_agent(
         
         async def context_injected_agent(prompt: str) -> str:
             if not _HAS_OTEL:
-                return await _maybe_await(original_agent(prompt))
-                
+                return await _maybe_await(original_agent(prompt, **(persona_kwargs or {})))
             # Set conversation context in baggage
             ctx = baggage.set_baggage("conv_id", conv_id)
             ctx = baggage.set_baggage("janus_simulation", "true", ctx)
@@ -242,8 +241,9 @@ def _create_context_aware_agent(
                     span.set_attribute("janus.turn_idx", int(turn_idx))
                 
                 # Execute agent
-                result = await _maybe_await(original_agent(prompt))
-                
+                result = await _maybe_await(
+    original_agent(prompt, **(persona_kwargs or {}))
+)
                 # Record response
                 truncated_response = result[:200] + "..." if len(result) > 200 else result
                 span.set_attribute("agent.response", truncated_response)
